#[non_exhaustive]pub enum CollectionError {
TooFew {
min: usize,
actual: usize,
},
TooMany {
max: usize,
actual: usize,
},
InvalidBounds {
min: usize,
max: usize,
},
ZeroCapacity,
Duplicate,
}Expand description
Error returned by bounded collection operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TooFew
The collection has fewer elements than the required minimum.
Fields
TooMany
The collection has more elements than the allowed maximum.
Fields
InvalidBounds
The const generic bounds are invalid (MIN > MAX).
ZeroCapacity
A capacity of zero was requested where a positive capacity is required.
Duplicate
A duplicate key or element was supplied where uniqueness is required.